@@ -96,20 +96,17 @@ void remove_socket_events(event_handler * handler, socket_event_source const* co
 		return;
 	}
 
-	auto socket_event_filter = [&](event_loop::Events::value_type const& ev) -> bool {
-		if (ev.first != handler) {
-			return false;
+	auto socket_event_filter = [&](event_base const& ev) -> bool {
+		if (ev.derived_type() == socket_event::type()) {
+			return std::get<0>(static_cast<socket_event const&>(ev).v_) == source;
 		}
-		else if (ev.second->derived_type() == socket_event::type()) {
-			return std::get<0>(static_cast<socket_event const&>(*ev.second).v_) == source;
-		}
-		else if (ev.second->derived_type() == hostaddress_event::type()) {
-			return std::get<0>(static_cast<hostaddress_event const&>(*ev.second).v_) == source;
+		else if (ev.derived_type() == hostaddress_event::type()) {
+			return std::get<0>(static_cast<hostaddress_event const&>(ev).v_) == source;
 		}
 		return false;
 	};
 
-	handler->event_loop_.filter_events(socket_event_filter);
+	handler->filter_events(socket_event_filter);
 }
 
 socket_event_flag change_socket_event_handler(event_handler * old_handler, event_handler * new_handler, socket_event_source const* const source, socket_event_flag remove)
@@ -130,10 +127,10 @@ socket_event_flag change_socket_event_handler(event_handler * old_handler, event
 #endif
 
 	socket_event_flag ret = socket_event_flag{};
-	auto socket_event_filter = [&](event_loop::Events::value_type & ev) -> bool {
-		if (ev.first == old_handler) {
-			if (ev.second->derived_type() == socket_event::type()) {
-				auto & sev = static_cast<socket_event const&>(*ev.second);
+	auto socket_event_filter = [&](event_handler*& h, event_base const& ev) -> bool {
+		if (h == old_handler) {
+			if (ev.derived_type() == socket_event::type()) {
+				auto & sev = static_cast<socket_event const&>(ev);
 				if (std::get<0>(sev.v_) == source) {
 					auto const flag = std::get<1>(sev.v_);
 #if DEBUG_SOCKETEVENTS
@@ -144,12 +141,12 @@ socket_event_flag change_socket_event_handler(event_handler * old_handler, event
 						return true;
 					}
 					ret |= flag;
-					ev.first = new_handler;
+					h = new_handler;
 				}
 			}
-			else if (ev.second->derived_type() == hostaddress_event::type()) {
-				if (std::get<0>(static_cast<hostaddress_event const&>(*ev.second).v_) == source) {
-					ev.first = new_handler;
+			else if (ev.derived_type() == hostaddress_event::type()) {
+				if (std::get<0>(static_cast<hostaddress_event const&>(ev).v_) == source) {
+					h = new_handler;
 				}
 			}
 		}
@@ -169,9 +166,9 @@ bool FZ_PRIVATE_SYMBOL has_pending_event(event_handler * handler, socket_event_s
 
 	bool ret = false;
 
-	auto socket_event_filter = [&](event_loop::Events::value_type const& ev) -> bool {
-		if (ev.first == handler && ev.second->derived_type() == socket_event::type()) {
-			auto const& socket_ev = static_cast<socket_event const&>(*ev.second).v_;
+	auto socket_event_filter = [&](event_base const& ev) -> bool {
+		if (ev.derived_type() == socket_event::type()) {
+			auto const& socket_ev = static_cast<socket_event const&>(ev).v_;
 			if (std::get<0>(socket_ev) == source && std::get<1>(socket_ev) & event) {
 				ret = true;
 			}
@@ -179,7 +176,7 @@ bool FZ_PRIVATE_SYMBOL has_pending_event(event_handler * handler, socket_event_s
 		return false;
 	};
 
-	handler->event_loop_.filter_events(socket_event_filter);
+	handler->filter_events(socket_event_filter);
 
 	return ret;
 }
